# 贡献者公约行为准则

## 我们的誓言

作为成员、贡献者和领导者，我们承诺让参与我们社区的每个人都能获得无骚扰的体验，无论其年龄、体型、可见或不可见的残疾、种族、性别、性别特征、性别认同和表达、经验水平、教育程度、社会经济地位、国籍、个人外貌、种族、种姓、肤色、宗教、或性认同和性取向如何。

我们承诺以有助于建立一个开放、热情、多元、包容和健康的社区的方式行事和互动。

## 我们的标准

有助于为我们的社区创造积极环境的行为示例包括：

* 对他人表现出同理心和善意
* 尊重不同的意见、观点和经验
* 给予并优雅地接受建设性的反馈
* 承担责任并向受我们要错误影响的人道歉，并从中吸取教训
* 不仅关注我们个人的利益，而且关注社区的整体利益

不可接受的行为示例包括：

* 使用性语言或图像，以及任何形式的性关注或求爱
* 挑衅、侮辱或贬损性评论，以及人身或政治攻击
* 公开或私下的骚扰
* 未经明确许可，发布他人的私人信息，如物理地址或电子邮件地址
* 其他在专业环境中可能有理由被认为是不适当的行为

## 执行责任

社区领导者负责阐明和执行我们的可接受行为标准，并将对任何他们认为不适当、威胁性、冒犯性或有害的行为采取适当和公平的纠正措施。

社区领导者有权并有责任删除、编辑或拒绝不符合本行为准则的评论、提交、代码、维基编辑、问题和其他贡献，并在适当的时候沟通适度决定的理由。

## 适用范围

本行为准则适用于所有社区空间，也适用于个人在公共场所正式代表社区时。
代表我们社区的例子包括使用官方电子邮件地址、通过官方社交媒体账户发帖，或作为指定代表参加在线或离线活动。

## 执行

虐待、骚扰或其他不可接受行为的实例可以向负责执行的社区领导者报告，邮箱地址为：aimasteracc@gmail.com。
所有投诉都将得到迅速和公平的审查和调查。

所有社区领导者都有义务尊重任何事件报告者的隐私和安全。

## 执行准则

社区领导者在确定他们认为违反本行为准则的任何行为的后果时，将遵循这些社区影响准则：

### 1. 纠正 (Correction)

**社区影响**：使用不适当的语言或其他在社区中被视为不专业或不受欢迎的行为。

**后果**：社区领导者的私人书面警告，明确违规的性质并解释为什么该行为是不适当的。可能会要求公开道歉。

### 2. 警告 (Warning)

**社区影响**：通过单一事件或一系列行为造成的违规。

**后果**：带有持续行为后果的警告。在指定的时间段内，禁止与相关人员进行互动，包括与执行行为准则的人员进行未经请求的互动。这包括避免在社区空间以及社交媒体等外部渠道进行互动。违反这些条款可能会导致暂时或永久禁言。

### 3. 暂时禁言 (Temporary Ban)

**社区影响**：严重违反社区标准，包括持续的不适当行为。

**后果**：在指定的时间段内，暂时禁止与社区进行任何形式的互动或公开交流。在此期间，不允许与相关人员进行公开或私下的互动，包括与执行行为准则的人员进行未经请求的互动。违反这些条款可能会导致永久禁言。

### 4. 永久禁言 (Permanent Ban)

**社区影响**：表现出违反社区标准的模式，包括持续的不适当行为、对他人的骚扰，或针对某些类别的个人的攻击或贬低。

**后果**：永久禁止在社区内进行任何形式的公开互动。

## 归属

本行为准则改编自 [Contributor Covenant][homepage] 2.1 版本，可从以下网址获得：
[https://www.contributor-covenant.org/version/2/1/code_of_conduct.html][v2.1]

社区影响准则受到 [Mozilla 行为准则执行阶梯][Mozilla CoC] 的启发。

[homepage]: https://www.contributor-covenant.org
[v2.1]: https://www.contributor-covenant.org/version/2/1/code_of_conduct.html
[Mozilla CoC]: https://github.com/mozilla/diversity
